AlekSIS (School Information System) — App Χρόνος (digital timetables)
=====================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS`_ platform.

Features
--------

* Show absent groups in timetable
* Show absent teachers in timetable
* Show affected groups in timetable
* Show affected teachers in timetable
* Timetables per day
* Timetables per group
* Timetables per person
* Timetables per room
* Timetables per week

Licence
-------

::

  Copyright © 2018, 2019, 2020 Jonathan Weth <wethjo@katharineum.de>
  Copyright © 2018, 2019 Frank Poetzsch-Heffter <p-h@katharineum.de>
  Copyright © 2019, 2020 Dominik George <dominik.george@teckids.org>
  Copyright © 2019 Julian Leucker <leuckeju@katharineum.de>
  Copyright © 2019 Tom Teichler <tom.teichler@teckids.org>
  Copyright © 2019 Hangzhi Yu <yuha@katharineum.de>

  Licenced under the EUPL, version 1.2 or later

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

.. _AlekSIS: https://aleksis.org/
.. _European Union Public Licence: https://eupl.eu/
